@@ -9,18 +9,16 @@ import copy
 import time
 import threading
 import requests
+import karafs
 
 try:
     from . import moves
-except ImportError:
-    import moves
-
-try:
     from . import server
 except ImportError:
+    import moves
     import server
 
-VERSION = '0.0.17'
+VERSION = '0.0.22'
 
 class Ansi:
     """ The terminal ansi chars """
@@ -97,8 +95,6 @@ class Piece:
             return result
         if dst in result:
             return True
-        if self.name == Piece.PAWN:
-            return False
         return False
 
 class Game:
@@ -126,8 +122,8 @@ class Game:
         self.selected_cell = None
 
         # the player names
-        self.white_player = 'White'
-        self.black_player = 'Black'
+        self.white_player = karafs.gen_str('en')
+        self.black_player = karafs.gen_str('en')
 
         # game status
         self.is_end = False
@@ -697,6 +693,8 @@ def online_connect(target, options=[], arguments=[]):
             turn = render[0]
             render = render[1]
             print(render)
+            if 'Checkmate' in render:
+                return
             if turn == my_color:
                 command = input(turn + ' Turn >>> ').strip()
                 if command == '':
@@ -715,6 +713,10 @@ def run(args=[]):
 
     game_file_name = 'game.tchess'
 
+    # disable ansi for windows
+    if os.name == 'nt':
+        args.append('--no-ansi')
+
     # parse the arguments
     options = [arg for arg in args if arg.startswith('-')]
     arguments = [arg for arg in args if not arg.startswith('-')]
@@ -863,7 +865,10 @@ def run(args=[]):
             print(Ansi.GREEN + 'Checkmate!' + Ansi.RESET + (' ' * (len(Game.ROW_SEPARATOR)-10)))
             color = Ansi.CYAN if game.winner == 'white' else Ansi.RED
             print(color + game.winner + Ansi.GREEN + ' won!' + Ansi.RESET + (' ' * (len(Game.ROW_SEPARATOR)-10)))
-            next_step = input('Press enter to continnue or type `back`: ').strip().lower()
+            if is_play:
+                next_step = ''
+            else:
+                next_step = input('Press enter to continnue or type `back`: ').strip().lower()
             if next_step == 'back':
                 game.is_end = False
                 game.winner = None
